import { default as React } from 'react';
import { Factory, CssKnownProps, CssRule, CssStyleCollection, CssVars } from '@cssfn/core';
import { EventHandler } from '@reusable-ui/hooks';
export interface ExcitableVars {
    filter: any;
    anim: any;
}
export declare const ifExcited: (styles: CssStyleCollection) => CssRule;
export declare const ifNotExcited: (styles: CssStyleCollection) => CssRule;
export interface ExcitableStuff {
    excitableRule: Factory<CssRule>;
    excitableVars: CssVars<ExcitableVars>;
}
export interface ExcitableConfig {
    filterExcite?: CssKnownProps['filter'];
    animExcite?: CssKnownProps['animation'];
}
/**
 * Adds a capability of UI to highlight itself to attract user's attention.
 * @param config  A configuration of `excitableRule`.
 * @returns An `ExcitableStuff` represents an excitable state.
 */
export declare const usesExcitable: (config?: ExcitableConfig) => ExcitableStuff;
export interface ExcitedChangeEvent {
    excited: boolean;
}
export interface ExcitableProps<TExcitedChangeEvent extends ExcitedChangeEvent = ExcitedChangeEvent> extends Partial<Pick<TExcitedChangeEvent, 'excited'>> {
}
export declare const enum ExcitableState {
    Unexcited = 0,
    Continue = 1,
    Excited = 2
}
export interface ExcitableApi<TElement extends Element = HTMLElement> {
    excited: boolean;
    state: ExcitableState;
    class: string | null;
    handleAnimationStart: React.AnimationEventHandler<TElement>;
    handleAnimationEnd: React.AnimationEventHandler<TElement>;
    handleAnimationCancel: React.AnimationEventHandler<TElement>;
}
export declare const useExcitable: <TElement extends Element = HTMLElement, TExcitedChangeEvent extends ExcitedChangeEvent = ExcitedChangeEvent>(props: ExcitableProps<TExcitedChangeEvent>) => ExcitableApi<TElement>;
export interface ControllableExcitableProps<TExcitedChangeEvent extends ExcitedChangeEvent = ExcitedChangeEvent> extends ExcitableProps<TExcitedChangeEvent> {
    onExcitedChange?: EventHandler<TExcitedChangeEvent>;
}
export declare const useControllableExcitable: <TElement extends Element = HTMLElement, TExcitedChangeEvent extends ExcitedChangeEvent = ExcitedChangeEvent>(props: ControllableExcitableProps<TExcitedChangeEvent>, excitableApi: ExcitableApi<TElement>) => void;
